facilities/overload.hpp

The facilities/overload.hpp header defines variadic macros that overload non-variadic macros to accept different numbers of parameters.

#### Usage

#include <boost/preprocessor/facilities/overload.hpp>

#### Contents

- BOOST_PP_OVERLOAD (v)

© Copyright Edward Diener 2011,2013

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)